#
# spec file for package fplll
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           fplll
%define lname   libfplll4
Version:        5.2.0
Release:        bp153.1.20
Summary:        Lenstra-Lovász Lattice Basis Reduction Algorithm Library
License:        LGPL-2.1+
Group:          Productivity/Scientific/Math
Url:            https://github.com/dstehle/fplll

#Git-Clone:	https://github.com/fplll/fplll
Source:         https://github.com/fplll/fplll/releases/download/%version/fplll-%version.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  mpfr-devel
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
fplll contains several algorithms on lattices that rely on
floating-point computations. This includes implementations of the
floating-point LLL reduction algorithm, offering different
speed/guarantees ratios. It also includes a rigorous floating-point
implementation of the Kannan-Fincke-Pohst algorithm that finds a
shortest non-zero lattice vector.

%package -n %lname
Summary:        Lenstra-Lovász Lattice Basis Reduction Algorithm Library
Group:          System/Libraries

%description -n %lname
fplll contains several algorithms on lattices that rely on
floating-point computations. This includes implementations of the
floating-point LLL reduction algorithm, offering different
speed/guarantees ratios. It also includes a rigorous floating-point
implementation of the Kannan-Fincke-Pohst algorithm that finds a
shortest non-zero lattice vector.

%package devel
Summary:        Development files for Lattice Basis Reduction with libfplll
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Obsoletes:      libfplll-devel < %version-%release
Provides:       libfplll-devel = %version-%release

%description -n fplll-devel
fplll contains several algorithms on lattices that rely on
floating-point computations. This includes implementations of the
floating-point LLL reduction algorithm, offering different
speed/guarantees ratios. It also includes a rigorous floating-point
implementation of the Kannan-Fincke-Pohst algorithm that finds a
shortest non-zero lattice vector.

This subpackage contains libraries and header files for developing
applications that want to make use of libfplll.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%defattr(-,root,root)
%_bindir/fplll
%_bindir/latticegen
%_bindir/latsieve
%_datadir/fplll/
%doc COPYING NEWS README.md

%files -n %lname
%defattr(-,root,root)
%_libdir/libfplll.so.*

%files -n fplll-devel
%defattr(-,root,root)
%_includedir/fplll*
%_libdir/libfplll.so
%_libdir/pkgconfig/*.pc

%changelog
* Mon Dec 25 2017 jengelh@inai.de
- Update to new upstream release 5.2.0
  * Bkz dump_gso in json
  * Improve pruner
  * BKZ with Z_NR<long>
  * Z_NR<long> support
  * Allow BOUNDED_LLL in Slide reduction and remove LLL from
    postprocessing by Michael Walter
  * Add Gram-matrix object
* Sat Sep  9 2017 jengelh@inai.de
- Update to new upstream release 5.1.0
  * CVP is not experimental any longer by implementing the
    resetting feature.
  * Pruner rewrite providing faster pruning, a new greedy pruning
    strategy, support for multiple solutions and a simpler API.
  * Support for external enumeration libraries paving the way for
    multithreaded/MPI/GPU enumeration libraries.
  * Gaussian Heuristic improved and renamed to
    `adjust_radius_to_gh_bound`.
  * Reduced calls to LLL during BKZ.
  * Evaluator rewrite/refactoring now supporting different
    evaluation strategies.
- Rename SRPM from libfplll to fplll.
  No binary packages are affected.
* Thu Oct 20 2016 jengelh@inai.de
- Update to new upstream release 5.0.3
  * No changelog was provided
* Mon Feb  2 2015 jengelh@inai.de
- Add git repository metadata
* Tue Feb  4 2014 jengelh@inai.de
- Update to new upstream release 4.0.4
  * compatibility for packages that still expect to build against
  libfplll version 3.
  * Compilation fixes: updates of config.sub and config.guess, and
  a better check that MPFR and GMP are installed.
* Fri May 17 2013 jengelh@inai.de
- Update to new upstream release 4.0.3
  * Fixed compiler issues for Cygwin and warnings
* Thu Nov 29 2012 jengelh@inai.de
- Update to new upstream release 4.0.1
  * Resolved compiler warnings about unused parameters
* Sat Aug 25 2012 dmitry@roshchin.org
- Update to version 4.0.0
  * BKZ reduction, available with `fplll -a bkz -b blocksize`
* Sun Feb 26 2012 scorot@free.fr
- fix build for SLE-11
- add missing %%post and %%postun scriplets
* Sun Nov 20 2011 werner.ho@gmx.de
- new version 3.1.3
* Tue Sep 27 2011 jengelh@medozas.de
- Initial package (version 3.1.2) for build.opensuse.org
